package com.example.dtf

import android.app.Application
import androidx.room.*
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch
import androidx.sqlite.db.SupportSQLiteDatabase
import com.example.dtf.db.AppDatabase
import com.example.dtf.models.User
import com.example.dtf.repositories.*
import dagger.Module
import dagger.Provides
import dagger.hilt.InstallIn
import dagger.hilt.components.SingletonComponent
import javax.inject.Singleton

@Module
@InstallIn(SingletonComponent::class)
object AppModule {
    @Provides
    @Singleton
    fun provideDatabase(app: Application) : AppDatabase {
        return Room.databaseBuilder(
            app,
            AppDatabase::class.java,
            AppDatabase.DB_NAME
        )
        .fallbackToDestructiveMigration()
        .build()
    }

    @Provides
    @Singleton
    fun provideCategoryRepository(db: AppDatabase) = CategoryRepository(db.categoryDao())

    @Provides
    @Singleton
    fun provideCommentRepository(db: AppDatabase) = CommentRepository(db.commentDao())

    @Provides
    @Singleton
    fun provideLikeRepository(db: AppDatabase) = LikeRepository(db.likeDao())

    @Provides
    @Singleton
    fun providePostRepository(db: AppDatabase) = PostRepository(db.postDao())

    @Provides
    @Singleton
    fun proviveUserRepository(db: AppDatabase) = UserRepository(db.userDao())
}