package com.example.dtf.repositories

import androidx.paging.*
import com.example.dtf.dao.CommentDao
import com.example.dtf.models.Comment
import javax.inject.Inject

class CommentRepository @Inject constructor(
    private val commentDao: CommentDao
) {
    suspend fun insert(comment: Comment) = commentDao.insert(comment)

    suspend fun update(comment: Comment) = commentDao.update(comment)

    suspend fun delete(comment: Comment) = commentDao.delete(comment)

    fun getAll() = commentDao.getAll()

    fun getById(id: Int) = commentDao.getById(id)

    fun getByPost(postId: Int) = Pager(
        PagingConfig(
            pageSize = 5,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { commentDao.getByPost(postId) }
    ).flow
}