package com.example.dtf.repositories

import androidx.paging.*
import com.example.dtf.dao.PostDao
import com.example.dtf.models.Post
import kotlinx.coroutines.flow.Flow
import javax.inject.Inject

class PostRepository @Inject constructor(
    private val postDao: PostDao
) {
    suspend fun insert(post: Post) = postDao.insert(post)

    suspend fun update(post: Post) = postDao.update(post)

    suspend fun delete(post: Post) = postDao.delete(post)

    fun getAll() = postDao.getAll()

    fun getById(id: Int) = postDao.getById(id)

    fun getByCategory(categoryId: Int) = Pager(
        PagingConfig(
            pageSize = 3,
            enablePlaceholders = false
        ),
        pagingSourceFactory = { postDao.getByCategory(categoryId.toString()) }
    ).flow
}