package com.example.dtf.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.dtf.PreferencesManager
import com.example.dtf.models.Category
import com.example.dtf.models.User
import com.example.dtf.repositories.CategoryRepository
import com.example.dtf.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class LoginViewModel @Inject constructor(
    private val userRepository: UserRepository,
    private val categoryRepository: CategoryRepository
) : ViewModel() {
    private val _successState = MutableLiveData<Boolean?>()
    val successState: LiveData<Boolean?>
        get() = _successState

    init {
        addAdmin()
    }

    fun calmSuccessState() {
        _successState.postValue(null)
    }

    fun login(sharedPref: PreferencesManager, username: String, password: String) {
        viewModelScope.launch {
            userRepository.getByUsernameAndPassword(username, password).collect {
                if (it == null) {
                    _successState.postValue(false)
                } else {
                    sharedPref.saveData("userId", it.id.toString())
                    sharedPref.saveData("isModerator", it.isModerator.toString())
                    _successState.postValue(true)
                }
            }
        }
    }

    private fun addAdmin() {
        viewModelScope.launch {
            userRepository.getAll().collect {
                if (it.size == 0) {
                    userRepository.insert(User(1, "admin", "admin", true))
                    categoryRepository.insert(Category(1, "Аниме"))
                    categoryRepository.insert(Category(2, "Игры"))
                    categoryRepository.insert(Category(3, "Фильмы"))
                }
            }
        }
    }
}