package com.example.dtf.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.dtf.PreferencesManager
import com.example.dtf.models.Category
import com.example.dtf.models.Post
import com.example.dtf.repositories.CategoryRepository
import com.example.dtf.repositories.PostRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import java.time.LocalDate
import java.util.Date
import javax.inject.Inject

@HiltViewModel
class NewPostViewModel @Inject constructor(
    private val postRepository: PostRepository,
    private val categoryRepository: CategoryRepository
) : ViewModel() {
    private val _addingPostState = MutableLiveData<Boolean?>(null)
    val addingPostState: LiveData<Boolean?>
        get() = _addingPostState

    private val _categories = MutableLiveData<List<Category>>(listOf())
    val categories: LiveData<List<Category>>
        get() = _categories

    fun retrieveCategories() {
        viewModelScope.launch {
            categoryRepository.getAll().collect {
                _categories.postValue(it)
            }
        }
    }

    fun calmAddingState() {
        _addingPostState.value = null
    }

    fun addPost(sharedPref: PreferencesManager, categoryId: Int, title: String, content: String) {
        if (!sharedPref.getData("isModerator", "false").toBooleanStrict()) return

        viewModelScope.launch {
            if (title.isNotEmpty() && content.isNotEmpty()) {
                postRepository.insert(
                    Post(
                        null,
                        title,
                        content,
                        Date(),
                        sharedPref.getData("userId", "0").toInt(),
                        categoryId
                    )
                )

                _addingPostState.postValue(true)
            } else {
                _addingPostState.postValue(false)
            }
        }
    }
}