package com.example.dtf.viewmodels

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.dtf.PreferencesManager
import com.example.dtf.models.Like
import com.example.dtf.repositories.CategoryRepository
import com.example.dtf.repositories.LikeRepository
import com.example.dtf.repositories.PostRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class PostsViewModel @Inject constructor(
    private val postRepository: PostRepository,
    private val categoryRepository: CategoryRepository,
    private val likeRepository: LikeRepository
) : ViewModel() {
    fun getLikes(postId: Int) = likeRepository.countByPost(postId)

    fun likePost(sharedPref: PreferencesManager, postId: Int) {
        val userId = sharedPref.getData("userId", "-1").toInt()

        if (userId == -1) return

        viewModelScope.launch {
            likeRepository.insert(Like(userId, postId))
        }
    }

    fun unlikePost(sharedPref: PreferencesManager, postId: Int) {
        val userId = sharedPref.getData("userId", "-1").toInt()

        if (userId == -1) return

        viewModelScope.launch {
            likeRepository.delete(Like(userId, postId))
        }
    }

    fun isLiked(sharedPref: PreferencesManager, postId: Int)
            = likeRepository.isLikedByUser(
        sharedPref.getData("userId", "-1").toInt(),
        postId
    )

    fun getCategories() = categoryRepository.getAll()

    fun getPostsListUiState(categoryId: Int) = postRepository.getByCategory(categoryId)
}