package com.example.dtf.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.dtf.PreferencesManager
import com.example.dtf.models.User
import com.example.dtf.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ProfileViewModel @Inject constructor(
    private val userRepository: UserRepository
) : ViewModel() {
    private val _user = MutableLiveData<User>()
    val user: LiveData<User>
        get() = _user

    fun retrieveUser(sharedPref: PreferencesManager) {
        val userId = sharedPref.getData("userId", "-1").toInt()

        if (userId == -1) return

        viewModelScope.launch {
            userRepository.getById(userId).collect {
                _user.postValue(it)
            }
        }
    }

    fun logout(sharedPref: PreferencesManager) {
        sharedPref.deleteData("userId")
        sharedPref.deleteData("isModerator")
    }
}