package com.example.dtf.viewmodels

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.dtf.PreferencesManager
import com.example.dtf.models.User
import com.example.dtf.repositories.UserRepository
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class RegisterViewModel @Inject constructor(
    private val userRepository: UserRepository
) : ViewModel() {
    private val _successState = MutableLiveData<Boolean?>()
    val successState: LiveData<Boolean?>
        get() = _successState

    fun calmSuccessState() {
        _successState.postValue(null)
    }

    fun register(username: String, password: String, confirmPassword: String) {
        if (username.length < 5 || username.length > 20) {
            _successState.postValue(false)
            return
        }

        if (password.length < 8 || password.length > 30) {
            _successState.postValue(false)
            return
        }

        if (password != confirmPassword) {
            _successState.postValue(false)
            return
        }

        viewModelScope.launch {
            userRepository.getByUsernameAndPassword(username, password).collect {
                if (it != null) {
                    _successState.postValue(false)
                } else {
                    userRepository.insert(User(null, username, password, false))
                    _successState.postValue(true)
                }
            }
        }
    }
}